@@ -121,7 +121,7 @@ void TestUtil::addLogLines(const QString &fileName, const QStringList &addedLine
         out.flush();
         data.close();
     } else {
-        QFAIL(QString::fromLatin1("Unable to open the test log file %1").arg(fileName).toUtf8());
+        QFAIL(QString::fromLatin1("Unable to open the test log file %1").arg(fileName).toUtf8().constData());
     }
 
     // Wait 3 secs to be sure the log file changed have been processed
